/*

                detectJava_OTF_NOTF_winLoaded.js v0.4.0
                By Eric Gerds   http://www.pinlady.net/PluginDetect/



 USAGE:
  1) When you download the PluginDetect script, make sure that the
     "Enable NOTF (NOT ON THE FLY) Java detection" checkbox is selected,
     so that NOTF Java detection is possible.
     See http://www.pinlady.net/PluginDetect/download/
     
  2) Insert the PluginDetect script into the <head> or <body> of your web page.

  3) Insert the output <div> into the <body> of your HTML page. This <div> will receive the
     plugin detection results:
        <div id="javaresult"></div>

  4) If you wish to use the plugindetect <div>, then insert it into the <body>.
     This <div> temporarily holds any Java applets that are inserted into the web page,
     but only when these applets are needed for detection.
     For example:
        <div id="plugindetect" style="right:0px; top:0px; position:absolute;"></div>
     This step is optional, as PluginDetect will create and insert the <div> automatically 
     when needed.

  5) Insert this script AFTER the PluginDetect script. It does not matter if this script
     is before or after the output <div> and the plugindetect <div>, because it waits for the
     web page to load before plugin detection begins.

  6) Get a copy of the "getJavaInfo.jar" jarfile. The jarfile is needed for Java detection.
     Adjust the value of the "jarfile" variable (given in the code below) to reflect the 
     jarfile name and path. Remember, the jarfile path is relative to the web page itself.

     Examples...

     If your web page is at      http://www.mysite.com/webpage.htm
     and you have the jarfile at http://www.mysite.com/getJavaInfo.jar
     then jarfile = "getJavaInfo.jar"

     If your web page is at       http://www.mysite.com/webpage.htm
     and you have the jarfile at  http://www.mysite.com/stuff/getJavaInfo.jar
     then jarfile = "stuff/getJavaInfo.jar"

  7) Feel free to change this script, remove comments, etc... to fit your own needs.


*/


(function(){

// GLOBAL VARIABLES
var $$ = PluginDetect,

  minVersion = "1,6,0,10",      // minimum version of Java we are trying to detect

// The path of the jarfile is relative to the web page ( NOT relative to this
// external javascript file!!! ). Only the very first Java PluginDetect command that is executed
// needs to have the jarfile input argument. You do not have to specify this input arg in
// any subsequent Java PluginDetect commands.
 jarfile = "../files/getJavaInfo.jar",

// If the verifyTags input argument is not specified or is null, then PluginDetect assumes
// a default value. Only the very first Java PluginDetect command
// would need to have the verifyTags input argument, if at all. You do not have to specify
// this input arg in any subsequent Java PluginDetect commands.
 verifyTags = null,

// output <div>. Detection results are placed in this <div>.
 out;

// Add text to output node
var docWrite = function(text){
     if (out){
        if (text){
          text = text.replace(/&nbsp;/g,"\u00a0");
          out.appendChild(document.createTextNode(text));
        };
        out.appendChild(document.createElement("br"));
     };
};  // end of function



// If we use the beforeInstantiate method, then use it BEFORE any other PluginDetect method.
// var F = function(){};
// if ($$.beforeInstantiate) $$.beforeInstantiate("Java", F);




// This event handler writes the detection results to the web page
function displayResults($){


  // Test whether Java is installed or not.
  //
  // Note that $$.isMinVersion("Java") is equivalent to $$.isMinVersion("Java", "0").
  docWrite("Java (using <applet> and/or <object> tag) installed & enabled: " +
      ($.isMinVersion("Java") >= 0 ? "true" : "false"));


  // Display the highest installed Java version.
  docWrite("Highest Installed Java Version: " + $.getVersion("Java"));


  // Check if some minimum Java version is installed
  var JavaStatus = $.isMinVersion("Java", minVersion);

  if (JavaStatus == 1){
     docWrite("Java " + minVersion + " or higher (using <applet> and/or <object> tag) is installed & enabled.");
  }

  else if (JavaStatus == 0){
     docWrite("Java installed & enabled but version is unknown");
  }

  else if (JavaStatus == -0.1){
     docWrite("Java installed & enabled but version is < " + minVersion);
  }

  else if (JavaStatus == -0.2){
     docWrite("Java installed but not enabled");
  }

  // if this function is called by $.onDetectionDone(), then detection has completed,
  // and so -.5/+.5 would not occur.
  else if (JavaStatus == -0.5 || JavaStatus == 0.5){
      docWrite("Java detection: not completed yet, requires NOTF detection.");
  }

  else if (JavaStatus == -1){
     docWrite("Java not installed / not enabled");
  };




  // Get extra info on the Java plugin.
  var INFO = $.getInfo ? $.getInfo("Java") : null;
  if (INFO && typeof INFO.vendor != "undefined"){  // verify that INFO object has information

     if (INFO.OTF==0) docWrite("Java detection: completed ON THE FLY (OTF)")
     else if (INFO.OTF==2) docWrite("Java detection: completed NOT ON THE FLY (NOTF)")
     
     // if this function is called by $.onDetectionDone(), then detection has completed,
     // and so this last 'else' would not occur.
     else docWrite("Java detection: not completed yet, requires NOTF detection.");

     docWrite("Deployment Toolkit browser plugin installed & enabled: " +
        (INFO.DeploymentToolkitPlugin ? "true" : "false"));

     docWrite("Next-Generation Java Plugin2 installed & enabled: " +
       (INFO.isPlugin2 ==1 ? "true": (INFO.isPlugin2==-1 ? "false" : "unknown"))
       );

     // INFO.All_versions array lists ALL Java versions found from all sources
     if (INFO.All_versions.length>1)
        docWrite("Multiple Java versions detected: " + INFO.All_versions.join(" & "));

     if (INFO.vendor.length > 0) docWrite("Java vendor: " + INFO.vendor);

     // Data from navigator.plugins array
     if (INFO.name.length > 0) 
         docWrite("Java plugin name: " + INFO.name);
     if (INFO.description.length > 0) 
         docWrite("Java plugin description: " + INFO.description);

     if (INFO.objectTag!==null)
       docWrite("Java (using HTML5 compatible <object> tag) installed & enabled: " + (INFO.objectTag>=0?"true":"false") +
         (INFO.objectTag==0 ? "  [but Javascript/Java bridge was not verified for this tag]" : "")
       );

     if (INFO.appletTag!==null)
       docWrite("Java (using <applet> tag) installed & enabled: " + (INFO.appletTag>=0?"true":"false") +
         (INFO.appletTag==0 ? "  [but Javascript/Java bridge was not verified for this tag]" : "")
       );


     // For IE, you can also use the
     //  <object> tag with classid="clsid:8AD9C840-044E-11D1-B3E9-00805F499D93"
     // to display a Java applet.
     if ($.isIE && INFO.objectTagActiveX!==null)
       docWrite("Java (using <object> tag with Oracle/Sun Java ActiveX) installed & enabled: " + (INFO.objectTagActiveX>=0?"true":"false") +
         (INFO.objectTagActiveX==0 ? "  [but Javascript/Java bridge was not verified for this tag]" : "")
       );


      var out, e, x, PLUGIN = INFO.PLUGIN, T =
          ["file.encoding", "file.encoding.pkg", "file.separator", "java.class.path",
           "java.class.version", "java.compiler", "java.home", "java.io.tmpdir",
           "java.version", "java.vendor", "java.vendor.url", "user.dir", "user.home",
           "java.vm.name", "java.vm.specification.name", "java.vm.specification.vendor",
           "java.vm.specification.version", "java.vm.vendor", "java.vm.version",
           "java.runtime.name", "java.runtime.version", "path.separator", "java.specification.name",
           "java.specification.version", "java.specification.vendor",
           "os.version", "os.name", "os.arch"];

      // Query instantiated Java applet to get extra info
      if (PLUGIN){
          docWrite("");
          docWrite("JAVA APPLET QUERY USING java.lang.System.getProperty(): ")
          for (x=0;x<T.length;x++){
             out=null;
             try{out = PLUGIN.getProp(T[x]) + " "}
             catch(e){};
             if (typeof out=="string" && out.length>1) docWrite(T[x] + ": " + out);
          };
          docWrite("");
      };

  };

  
  docWrite("navigator.javaEnabled(): " + navigator.javaEnabled());
  
  if ($.isIE) docWrite("ActiveX / ActiveX scripting enabled: " + $$.ActiveXEnabled); 


};  // end of displayResults()




// Execute some function after the window has loaded
$$.onWindowLoaded(
  function(){
    
     // output <div>. Detection results are placed in this <div>.
     out = document.getElementById("javaresult");

     docWrite("[window.onload event has fired successfully.]");
     if ($$.Plugins.java){
       if ($$.Plugins.java.NOTF) docWrite("[This detector is capable of OTF & NOTF Java detection.");
       else docWrite("[This detector is capable of OTF Java detection.");
     };
     docWrite("Detection occurs after window.onload event has fired.]");
     docWrite("");

     // Start Java plugin detection, using the jarfile if needed.
     // When Java detection has been completed, then run the displayResults() method.
     // The onDetectionDone('Java') method can handle both OTF and NOTF.
     //
     // onDetectionDone() == 1 means detection has completed (OTF)
     // == 0 means detection not completed yet (and thus NOTF detection is being performed)
     // == -1 means detection unable to proceed due to error
     $$.onDetectionDone('Java', displayResults, jarfile, verifyTags);
  }
);


})();   // end of anonymous function

